DsaAlgorithm

Enum DsaAlgorithm 

pub enum DsaAlgorithm {
Show 28 variants MlDsa44, MlDsa65, MlDsa87, MlDsa44Rsa2048PssSha256, MlDsa44Rsa2048Pkcs15Sha256, MlDsa44Ed25519SHA512, MlDsa44EcdsaP256SHA256, MlDsa44EcdsaBrainpoolP256r1SHA256, MlDsa65Rsa3072PssSHA512, MlDsa65Rsa3072Pkcs15SHA512, MlDsa65EcdsaP256SHA512, MlDsa65EcdsaBrainpoolP256r1SHA512, MlDsa65Ed25519SHA512, MlDsa87EcdsaP384SHA512, MlDsa87EcdsaBrainpoolP384r1SHA512, MlDsa87Ed448SHA512, SlhDsaSha2_128s, SlhDsaSha2_128f, SlhDsaSha2_192s, SlhDsaSha2_192f, SlhDsaSha2_256s, SlhDsaSha2_256f, SlhDsaShake128s, SlhDsaShake128f, SlhDsaShake192s, SlhDsaShake192f, SlhDsaShake256s, SlhDsaShake256f,
}
The permissible algorithms for the AlgorithmIdentifier type.

Variants



MlDsa44



MlDsa65



MlDsa87



MlDsa44Rsa2048PssSha256



MlDsa44Rsa2048Pkcs15Sha256



MlDsa44Ed25519SHA512



MlDsa44EcdsaP256SHA256



MlDsa44EcdsaBrainpoolP256r1SHA256



MlDsa65Rsa3072PssSHA512



MlDsa65Rsa3072Pkcs15SHA512



MlDsa65EcdsaP256SHA512



MlDsa65EcdsaBrainpoolP256r1SHA512



MlDsa65Ed25519SHA512



MlDsa87EcdsaP384SHA512



MlDsa87EcdsaBrainpoolP384r1SHA512



MlDsa87Ed448SHA512



SlhDsaSha2_128s



SlhDsaSha2_128f



SlhDsaSha2_192s



SlhDsaSha2_192f



SlhDsaSha2_256s



SlhDsaSha2_256f



SlhDsaShake128s



SlhDsaShake128f



SlhDsaShake192s



SlhDsaShake192f



SlhDsaShake256s



SlhDsaShake256f

Implementations

Source

impl DsaAlgorithm

pub fn is_composite(&self) -> bool

Check if the algorithm is a composite or pure algorithm

Returns

True if the algorithm is a composite algorithm, false otherwise

pub fn get_oid(&self) -> String

Get the OID for the algorithm

Returns

The OID for the algorithm

pub fn from_oid(oid: &str) -> Option<DsaAlgorithm>

Get the DSA algorithm from an OID

Arguments
  • oid - The OID of the DSA algorithm
Returns

The DSA algorithm or None if the OID is not found